Skip to contents

Give advice about good practices when building R packages. Advice includes functions and syntax to avoid, package structure, code complexity, code formatting, etc.

Author

Maintainer: Mark Padgham mark@ropensci.org (ORCID)

Authors:

Other contributors: