Skip to contents

You tell agents to directly use this function in order for them to learn the skill. If you want to use the skill yourself to guide an agent, then use the use_skill_gp function.

Usage

learn_skill_gp()

Value

The content of the file system.file("skills", "goodpractice4agents.md", package = "goodpractice"))

Examples

if (FALSE) { # \dontrun{
learn_gp_skill()
} # }