The package must be extracted into the working directory, as usual.
Usage
prep_expressions(state, version = NULL, quiet)
Arguments
- state
GP state.
- version
Currently ignored.
Value
The modified state, with the closures in a named list.
Details
We can use lintr to extract the functions, but need to use
our own code (based on similar code in functionMap) to
get the right collation order.