| checks_by_group | R Documentation |
Returns the names of all checks that belong to the given group(s). This makes it easy to run or inspect a specific category of checks without knowing individual check names.
checks_by_group(...)
... |
Group names as character strings. Use |
Character vector of check names
# run only DESCRIPTION and namespace checks
checks_by_group("description", "namespace")
# see what the lintr group covers
checks_by_group("lintr")
# See all checks by group:
lapply(all_check_groups(), checks_by_group)
# use directly in gp()
## Not run:
gp(".", checks = checks_by_group("description", "lintr"))
## End(Not run)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.