Learn R Programming

goodpractice (version 1.2.0)

checks_by_group: Select checks by check group

Description

Returns the names of all checks that belong to the given group(s). This makes it easy to run or inspect a specific category of checks without knowing individual check names.

Usage

checks_by_group(...)

Value

Character vector of check names

Arguments

...

Group names as character strings. Use all_check_groups() to see available names.

See Also

Other check_groups: all_check_groups(), all_checks(), default_checks(), describe_check(), describe_check_groups(), tidyverse_checks()

Examples

Run this code
# run only DESCRIPTION and namespace checks
checks_by_group("description", "namespace")

# see what the lintr group covers
checks_by_group("lintr")
# See all checks by group:
lapply(all_check_groups(), checks_by_group)
# use directly in gp()
if (FALSE) {
  gp(".", checks = checks_by_group("description", "lintr"))
}

Run the code above in your browser using DataLab