Returns full descriptions of all registered check groups.
Value
A named list of each check group defined in all_check_groups(),
with text descriptions of each group.
Examples
# Names of all check groups:
all_check_groups()
#> [1] "covr" "cyclocomp" "description"
#> [4] "lintr" "namespace" "rcmdcheck"
#> [7] "rd" "revdep" "roxygen2"
#> [10] "code_structure" "package_structure" "spelling"
#> [13] "tidyverse" "urlchecker" "vignette"
# And corresponding descriptions:
describe_check_groups()
#> $covr
#> [1] "Test coverage report from 'covr' package."
#>
#> $cyclocomp
#> [1] "Function cyclocomplexity with the 'cyclocomp' package; default limit of 50."
#>
#> $description
#> [1] "Check common issues with DESCRIPTION files, including formatting issues with URLs, DOIs, BugReports, package names, and author and contributor roles"
#>
#> $lintr
#> [1] "Check package linting with the 'lintr' package (85 linters in total)."
#>
#> $namespace
#> [1] "Check import and export patterns in NAMESPACE file"
#>
#> $rcmdcheck
#> [1] "Run 'R CMD check' via the 'rcmdcheck' package. ~200 checks for documentation, namespace, compilation, tests, vignettes, CRAN compliance."
#>
#> $rd
#> [1] "Check whether or not 'man/*.Rd' function documentation includes both example code and return values (regardless of whether or not documentation files are generated by 'Roxygen2')."
#>
#> $revdep
#> [1] "Check whether package has reverse dependencies, and recommending running 'reddev' package if so."
#>
#> $roxygen2
#> [1] "Only for packages within use 'Roxygen2' to generate documentation. Checks for best practices in Roxygen2 tag usage, flags any unknown tags, and ensures 'inheritParams' is used correctly."
#>
#> $code_structure
#> [1] "Common issues like duplicated or unused function bodies, that 'print()' returns insivibly, that 'on.exit()' uses 'add = TRUE', and checks on function length (default max50 lines)."
#>
#> $package_structure
#> [1] "Generic checks like whether a package has a README, a NEWS file, or whether all files use a '.R' extension, and not '.r'."
#>
#> $spelling
#> [1] "Check spelling with the 'spelling' package."
#>
#> $tidyverse
#> [1] "Check compliance with the Tidyverse style guide; mostly via 'lintr' package. (These checks are not run by default; and only if 'tidyverse_checks()' are added to 'checks_by_group()'."
#>
#> $urlchecker
#> [1] "Check whether all URLs are valid, includingidentifying any redirects."
#>
#> $vignette
#> [1] "Check that vignette code does not use either 'rm()' or 'setwd()'."
#>