Function for AI agents to run and learn how to use the 'goodpractice' package.
Source:R/api.R
learn_skill_gp.RdYou tell agents to directly use this function in order for them to learn the skill. If you want to use the skill yourself to guide an agent, then use the use_skill_gp function.