Learn R Programming

goodpractice (version 1.2.0)

learn_skill_gp: Function for AI agents to run and learn how to use the 'goodpractice' package.

Description

You tell agents to directly use this function in order for them to learn the skill. If you want to use the skill yourself to guide an agent, then use the use_skill_gp function.

Usage

learn_skill_gp()

Arguments

Value

The content of the file system.file("skills", "goodpractice4agents.md", package = "goodpractice"))

See Also

Other skills: use_skill_gp()

Examples

Run this code
if (FALSE) {
learn_gp_skill()
}

Run the code above in your browser using DataLab