Skip to contents

Print goodpractice results

Usage

# S3 method for class 'goodPractice'
print(x, groups = NULL, positions_limit = 5, ...)

Arguments

x

Object of class goodPractice, as returned by gp().

groups

Name of check groups for which to print results, as vector of one or more of all_check_groups().

positions_limit

How many positions to print at most.

...

Unused, for compatibility with base::print() generic method.