powered by
Print goodpractice results
# S3 method for goodPractice print(x, groups = NULL, positions_limit = 5, ...)
Object of class goodPractice, as returned by gp().
goodPractice
gp()
Name of check groups for which to print results, as vector of one or more of all_check_groups().
all_check_groups()
How many positions to print at most.
Unused, for compatibility with base::print() generic method.
base::print()
Other output: export_json(), results()
export_json()
results()